@@ -40,11 +40,11 @@ namespace KCDDB
 
       CDInfoList lookupResponse() const;
 
-    signals:
+    Q_SIGNALS:
 
       void finished( KCDDB::Result );
 
-    protected slots:
+    protected Q_SLOTS:
       void lookupFinished( );
 
     private:
